@@ -1,9 +1,12 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.12
 
+import asyncio
 import socket
 import uuid
+
+import context  # Ensures paho is in PYTHONPATH
+
 import paho.mqtt.client as mqtt
-import asyncio
 
 client_id = 'paho-mqtt-python/issue72/' + str(uuid.uuid4())
 topic = client_id
@@ -85,7 +88,7 @@ class AsyncMqttExample:
 
         aioh = AsyncioHelper(self.loop, self.client)
 
-        self.client.connect('mqtt.eclipse.org', 1883, 60)
+        self.client.connect('mqtt.eclipseprojects.io', 1883, 60)
         self.client.socket().setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, 2048)
 
         for c in range(3):
