@@ -1,11 +1,12 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.11
 
 import socket
 import uuid
-import paho.mqtt.client as mqtt
 from select import select
 from time import time
 
+import paho.mqtt.client as mqtt
+
 client_id = 'paho-mqtt-python/issue72/' + str(uuid.uuid4())
 topic = client_id
 print("Using client_id / topic: " + client_id)
@@ -64,7 +65,7 @@ class SelectMqttExample:
         self.client.on_message = self.on_message
         self.client.on_disconnect = self.on_disconnect
 
-        self.client.connect('mqtt.eclipse.org', 1883, 60)
+        self.client.connect('mqtt.eclipseprojects.io', 1883, 60)
         print("Socket opened")
         self.client.socket().setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, 2048)
 
