@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.11
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2016 Roger Light <roger@atchoo.org>
@@ -16,11 +16,12 @@
 # This shows an example of using the subscribe.simple helper function.
 
 import context  # Ensures paho is in PYTHONPATH
+
 import paho.mqtt.subscribe as subscribe
 
 topics = ['#']
 
-m = subscribe.simple(topics, hostname="mqtt.eclipse.org", retained=False, msg_count=2)
+m = subscribe.simple(topics, hostname="mqtt.eclipseprojects.io", retained=False, msg_count=2)
 for a in m:
     print(a.topic)
     print(a.payload)
